==> zio-aws-kafka_3-5.17.104.10-sources.jar: zio/aws/kafka/model/Iam.scala <==
package zio.aws.kafka.model
import zio.ZIO
import zio.aws.kafka.model.primitives.__boolean
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class Iam(enabled: Option[__boolean] = None) {
  def buildAwsValue(): software.amazon.awssdk.services.kafka.model.Iam = {
    import Iam.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kafka.model.Iam
      .builder()
      .optionallyWith(
        enabled.map(value => __boolean.unwrap(value): java.lang.Boolean)
      )(_.enabled)
      .build()
  }
  def asReadOnly: zio.aws.kafka.model.Iam.ReadOnly =
    zio.aws.kafka.model.Iam.wrap(buildAwsValue())
}
object Iam {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.kafka.model.Iam] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kafka.model.Iam =
      zio.aws.kafka.model.Iam(enabled.map(value => value))
    def enabled: Option[__boolean]
    def getEnabled: ZIO[Any, AwsError, __boolean] =
      AwsError.unwrapOptionField("enabled", enabled)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kafka.model.Iam
  ) extends zio.aws.kafka.model.Iam.ReadOnly {
    override val enabled: Option[__boolean] = scala
      .Option(impl.enabled())
      .map(value => zio.aws.kafka.model.primitives.__boolean(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.kafka.model.Iam
  ): zio.aws.kafka.model.Iam.ReadOnly = new Wrapper(impl)
}

==> zio-aws-kafka_3-5.17.177.1-sources.jar: zio/aws/kafka/model/Iam.scala <==
package zio.aws.kafka.model
import zio.ZIO
import zio.aws.kafka.model.primitives.__boolean
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class Iam(enabled: Optional[__boolean] = Optional.Absent) {
  def buildAwsValue(): software.amazon.awssdk.services.kafka.model.Iam = {
    import Iam.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kafka.model.Iam
      .builder()
      .optionallyWith(enabled.map(value => value: java.lang.Boolean))(_.enabled)
      .build()
  }
  def asReadOnly: zio.aws.kafka.model.Iam.ReadOnly =
    zio.aws.kafka.model.Iam.wrap(buildAwsValue())
}
object Iam {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.kafka.model.Iam] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kafka.model.Iam =
      zio.aws.kafka.model.Iam(enabled.map(value => value))
    def enabled: Optional[__boolean]
    def getEnabled: ZIO[Any, AwsError, __boolean] =
      AwsError.unwrapOptionField("enabled", enabled)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kafka.model.Iam
  ) extends zio.aws.kafka.model.Iam.ReadOnly {
    override val enabled: Optional[__boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.enabled())
      .map(value => value: __boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.kafka.model.Iam
  ): zio.aws.kafka.model.Iam.ReadOnly = new Wrapper(impl)
}
